/***************************************************************************
 *   Copyright (C) 2004 by Gerd Fleischer                                  *
 *   gerdfleischer@gmx.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KLINPOPUP_H_
#define _KLINPOPUP_H_

#define ID_STATUS_TEXT 10

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qtimer.h>
#include <qstring.h>
#include <qmap.h>

#include <kapplication.h>
#include <kmainwindow.h>
#include <ksystemtray.h>
#include <kaction.h>

#include "klinpopupview.h"
#include "systemtray.h"

class KPrinter;
class KToggleAction;
class KURL;
class SystemTray;

/**
 * This class serves as the main window for KLinPopup.  It handles the
 * menus, toolbars, and status bars.
 *
 * @short Main window class
 * @author Gerd Fleischer <gerdfleischer@gmx.de>
 * @version 0.1
 */
class KLinPopup : public KMainWindow
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    KLinPopup();

    /**
     * Default Destructor
     */
    virtual ~KLinPopup();

    void showPopup();
    
protected:
    void hideEvent(QHideEvent *);
    void closeEvent(QCloseEvent *);
    void focusInEvent(QFocusEvent *);
	    
public slots:
    void newPopup();
//    void quitKLinPopup();
    
private slots:
    void popupFileTimerDone();
    void signalNewMessage(QString, QString, QString);
    void replyPopup();
    void previousPopup();
    void nextPopup();
    void deletePopup();
    void optionsShowToolbar();
    void optionsShowStatusbar();
    void optionsConfigureKeys();
    void optionsConfigureToolbars();
    void optionsPreferences();
    void newToolbarConfig();

    void changeStatusbar(const QString& text);
    void changeCaption(const QString& text);
    void settingsChanged();
    
private:
    void setupAccel();
    void setupActions();
    void initSystemTray();
    void initTimer();
    void checkMessageMap();
    void createStatText();
    void readConfig();
    void saveConfig();
    

private:
    KLinPopupView *m_view;

    SystemTray *m_systemTray;
    KPrinter *m_printer;
    KToggleAction *m_toolbarAction;
    KToggleAction *m_statusbarAction;
    KAction *newPopupAction;
    KAction *replyPopupAction;
    KAction *previousPopupAction;
    KAction *nextPopupAction;
    KAction *deletePopupAction;
    
    bool startDocked;
    QString newPopupSound;
    bool isDockedOnly;
    int newMessageSignaling;
    int actualPopup;
    QTimer *popupFileTimer;
    QString messageText;
    QString popupFileDirectory;
    QString StatText;
    QMap<int, QString> popupSenderMap;
    QMap<int, QString> popupTimeMap;
    QMap<int, QString> popupMessageTextMap;
            
	    
};

#endif // _KLINPOPUP_H_

